Retrieves the name of network/animals? To get an account, register via the Lifewatch RShiny registration webpage.

listEtnProjects(usr = NULL, pwd = NULL, ...)

Arguments

usr

Username to connect to ETN database

pwd

Password to connect to ETN database

...

Reserved for internal use.

Value

Dataframe with name and type of networks.

Examples

listEtnProjects()
#> - Query mode: Post request to OpenCPU server
#> No encoding supplied: defaulting to UTF-8.
#>                                                                                 name
#> 1                                                                  2011_Bovenschelde
#> 2                                                                         2011_Loire
#> 3                                                                         2013_Foyle
#> 4                                                                          2013_Maas
#> 5                                                                          2014_Nene
#> 6                                                           2015_PhD_Gutmann_Roberts
#> 7                                                               2016_Diaccia_Botrona
#> 8                                                                        2017_Fremur
#> 9                                                                    2020_PhD_Winter
#> 10                                                                     Aberdeen 2017
#> 11                                       Acousic receiver array for the MOVE project
#> 12                     Acoustic array in the Ria de Vigo (Galicia, Spain) since 2024
#> 13   Acoustic data between 2026 and 2028 for rheophilic fish in weir-regulated Meuse
#> 14                                      Acoustic Ecology of Pelagic Fish Communities
#> 15                             Acoustic Monitoring of Bluefin Tuna in the Aegean Sea
#> 16              Acoustic receiver array in the Gudena River, Denmark, from 2004-2006
#> 17                          Acoustic receiver array in the River Hevring (2023-2028)
#> 18              Acoustic receiver array in the Zuidelijke Randmeren, the Netherlands
#> 19    Acoustic telemetry array active since 2019 to track species in Bristol Channel
#> 20    Acoustic telemetry array data for elasmobranch in Northern Ireland (2024-2030)
#> 21   Acoustic telemetry array in the river Oude IJssel (Germany and the Netherlands)
#> 22                      Acoustic telemetry array on the east cost of Corsica, France
#> 23    Acoustic telemetry data for Atlantic cod at an oil and gas platform in Denmark
#> 24         Acoustic telemetry data for blue crab in the S'Ena Arrubia lagoon (Italy)
#> 25          Acoustic telemetry data for coastal fishes in Marintique Island (France)
#> 26    Acoustic telemetry data for European eel (Anguilla anguilla) in the River Test
#> 27       Acoustic telemetry data for Lionfish distribution in Gökova Bay, Aegean Sea
#> 28    Acoustic telemetry data for Sakarya Telemetry Array in the Black Sea (Türkiye)
#> 29    Acoustic telemetry data from the Clew Bay and Achill region in west of Ireland
#> 30  Acoustic telemetry data of marine species monitored 6 French offshore wind farms
#> 31                     Acoustic telemetry data of the Super Smolt project, the Rhine
#> 32   Acoustic telemetry data on Allis shad migrating in the Oise River (Seine basin)
#> 33                                                   Acoustic telemetry in lake Osby
#> 34           Acoustic telemetry network in the Ecowende wind farm in the Netherlands
#> 35              Acoustic telemetry network in the harbours of IJmuiden and Rotterdam
#> 36     Acoustic telemetry network in the non-tidal River Scheldt and its tributaries
#> 37   Acoustic telemetry network in the North Sea and the Eastern Scheldt (2025-2028)
#> 38   Acoustic telemetry network in the western River Rhine and hinterlands 2025–2026
#> 39      Acoustic telemetry on Atlantic cod in the Horns Rev 2 offshore windmill farm
#> 40   Acoustic telemetry receiver array in Galway Bay and Dunkellin River (2015-2019)
#> 41                         Acoustic telemetry receiver array in Murcia Region, Spain
#> 42            Acoustic telemetry receiver array in the harinxma channel in Harlingen
#> 43               Acoustic telemetry receiver array in the Nederrijn-Lek, Netherlands
#> 44                 Acoustic telemetry receiver array in the North Sea from 2017-2018
#> 45                  Acoustic telemetry receiver array in the Orbetello lagoon, Italy
#> 46    Acoustic telemetry receiver array in the River Warnow (Germany) from 2011-2012
#> 47         Acoustic telemetry receiver array in the Waal river between 2025 and 2027
#> 48               Acoustic telemetry study in the Meuse river basin at Lith and Linne
#> 49                                                                      Albertkanaal
#> 50                                                              Albertkanaal_VPS_Ham
#> 51                                                          Albertkanaal_VPS_Hasselt
#> 52           An acoustic receiver network operating at 69 kHz in and around Blekinge
#> 53                                                                        ARAISOLA02
#> 54                                                                        ARAISOLA03
#> 55                                                                               Ars
#> 56                                                                          Artevigo
#> 57             Artisanal fisheries & wetland management: eel and mullet in SE Iberia
#> 58                                                 Azorean acoustic receiver network
#> 59         Balearic strategy for climate change monitoring and prediction in the Med
#> 60                                                         Balearic Tracking Network
#> 61                   Balearic Tracking Network - Spanish Deep Water Receiver Network
#> 62                                                       Baltic Sea Tracking Network
#> 63                                                            Basking_shark_Hebrides
#> 64                                                                            BECORV
#> 65    Behaviour of Cancer pagurus in proximity to a fish farm in Storfjorden, Norway
#> 66                           Belwind temporary acoustic receiver network 2020 - 2021
#> 67                                           Bergen's Ocean Acoustic Tracking System
#> 68  Blue crab telemetry monitoring in three lagoons, channels and coast of Occitanie
#> 69                                                                       Boddenhecht
#> 70                                                                              BPNS
#> 71                                                           Brasem Ijsselmeergebied
#> 72                                      British and Irish Tracking array (permanent)
#> 73                                               Brown trout in the Falkland Islands
#> 74                                                                    BTN_LOST_ARRAY
#> 75                                                      Canaries Angel Shark Project
#> 76                                                          Catalan Tracking Network
#> 77                                                   CMRC European Sea Bass Tracking
#> 78                                                            CODEVCO fish detectors
#> 79                          Connectivity of coastal fish in the French Mediterranean
#> 80                                                                        Conon 2017
#> 81                                                                       cpodnetwork
#> 82                                                                     DAbecasis PhD
#> 83                                                                     DAK 2018-2019
#> 84                                                          Dalalven Smolt Migration
#> 85                                                        Danish_southeastern_strait
#> 86                                            Danish Straits Acoustic Infrastructure
#> 87                                                                  Danube_Sturgeons
#> 88                                                                Delfzijl 2014-2015
#> 89                                                                             Demer
#> 90    Deployment of acoustic receivers in Carlingford Lough for the NorTrack project
#> 91                             Deployment of acoustic receivers in inner Lough Foyle
#> 92                             Deployment of acoustic receivers in outer Lough Foyle
#> 93             Deployment of acoustic receivers in rivers within the Foyle Catchment
#> 94      Deployment of an acoustic array in the North Channel for the STRAITS project
#> 95                                                                      Deveron 2016
#> 96                                                                             Dijle
#> 97                                                                         Dijle_VPS
#> 98                                                                        DTU-Skjern
#> 99    Dusky grouper´s resettlement - Acoustic telemetry in Maro-Cerro Gordo´s cliffs
#> 100   Duurzame economische dragers in Vlaamse kustvisserijgemeenschappen post-Brexit
#> 101                                                 Eel migration from source to sea
#> 102                                                                     Eemskanaal I
#> 103                                                                    Eemskanaal II
#> 104                                                                   Eemskanaal III
#> 105                                                                             EMMN
#> 106                                                                             ESGL
#> 107                                                      ETN_network_project_group_1
#> 108                                                      ETN_network_project_group_2
#> 109                                                      ETN_network_project_group_3
#> 110                                                      ETN_network_project_group_4
#> 111                                                      ETN_network_project_group_5
#> 112                                                      ETN_network_project_group_6
#> 113                                                      ETN_network_project_group_7
#> 114                                                      ETN_network_project_group_8
#> 115                                                      ETN_network_project_group_9
#> 116                                                          Euskal Tracking Network
#> 117   Evaluation of the effectiveness of the Balearic Islands Marine Reserve Network
#> 118                                                                FarmTrack_Spain22
#> 119     Fine scale acoustic telemetry array at Hinkley Point C water intakes in 2025
#> 120     Fine scale acoustic telemetry array at Hinkley Point C water intakes in 2026
#> 121  Fine-scale multispecies acoustic telemetry positioning system data at Helgoland
#> 122                                           Fisheries Industry Science Partnership
#> 123               Fisheries Innovation for sustainable SHared INTerchannEL resources
#> 124                                          Fish migration from source to Waddensea
#> 125                                                             FISHOWF_Array_France
#> 126                                                              Friesland 2011-2012
#> 127                                    Galician (NW Spain) acoustic Tracking Network
#> 128                                                                   Gudena_network
#> 129                              Haringvlietdam - Rhine-Meuse Delta Acoustic Network
#> 130    High-frequency acoustic telemetry array in the northwestern Mediterranean sea
#> 131  HR2 tech and 3D tracking of European eel in landlocked drinking water reservoir
#> 132 ICOD: array to monitor interaction between cod spawning grounds and salmon farms
#> 133                                                                  IG II Fish Pass
#> 134                                                                        Iller_VPS
#> 135                                        Immature bass acoustic stock surveillance
#> 136                                                                          IMR_OWF
#> 137                                                                    Inforbiomares
#> 138                                                       Infragravity waves project
#> 139                                                                  INTERREG_CANAPE
#> 140         Intra-lagoon ecological connectivity: migration surveys of European eels
#> 141                                                     Jersey Coastal Fish Tracking
#> 142                                                              JSATS-PalmaBay-2019
#> 143                                                   Kalmar Baltic Tracking Network
#> 144                                                           Kattegat Islands Array
#> 145                                                      Kiel Bight Acoustic Network
#> 146                                                                   Kornwerderzand
#> 147                                                                Lake_Anundsjo_VPS
#> 148                       Land-use change and human activity on anadromous salmonids
#> 149                                                                      Lauwersmeer
#> 150                                                                    Leopoldkanaal
#> 151        Le Tréport harbour receiver array in the Bresle estuary, northwest France
#> 152                                                                        Lifewatch
#> 153                                                   Lifewatch: additional stations
#> 154                                             Lifewatch: Porpoise Performance test
#> 155                                                                         Limfjord
#> 156                                             Ljusne Bay Salmon Spawning Migration
#> 157 Long-term array MOnitoring BEhaviour in Illas Atlánticas National Park, NW Spain
#> 158                                                                       LSTSTJ_MPA
#> 159                                                                          MacFish
#> 160       Mapping critical habitats of threatened shark species in the Algarve coast
#> 161                                                          Marble vs rainbow trout
#> 162                                                            MariagerFjord_network
#> 163        Marine Ecological connectivity and conseRvation in the MOZambique Channel
#> 164                                                                       MBA_Massmo
#> 165                                                                      MBA_Wavehub
#> 166                                                                     MBA_Whitsand
#> 167                                                                           MEPNSW
#> 168                                                          Middle_Danube_sturgeons
#> 169   Migration of pikeperch within the Lake Peipus complex (Estonia) from 2021-2023
#> 170                                                                      MIGRATOEBRE
#> 171                                                            MMERMAID_Array_France
#> 172                                                                      Mobula Imar
#> 173                             Monitoring Gibraltar Strait Using Acoustic Telemetry
#> 174                                                                 Moray Firth 2016
#> 175      Movement and habitat connectivity of Atlantic cod in a coastal fjord system
#> 176     Movement, Range Size and Habitat Utilization of magafish in Turkey 2019-2021
#> 177   Movements of cod, plaice, flounder and turbot in the western German Baltic Sea
#> 178   MPAs' effect on Balearic chondrichthyes' biodiversity using acoustic telemetry
#> 179                                                                         mrc_vliz
#> 180                                                                         NARVAEEL
#> 181                                                          Northern_Norfolk_Broads
#> 182                                                                 North_sea_wrecks
#> 183                                                                    NTNU-Gaulosen
#> 184                                                       NTNU River Nidelva Project
#> 185   Observing the effect of group dynamics on individual behavior in basking shark
#> 186                                                Open Protocols scientific testing
#> 187                                                                       Orsted Cod
#> 188                                                                  OTN-Hemnfjorden
#> 189                                                          OTN Loan - Beiarfjorden
#> 190                                                             OTN-Skjerstadfjorden
#> 191                                                     OTN Strait of Gibraltar Line
#> 192                                                                 OTN-Tosenfjorden
#> 193                                                           OTN VR2W Loan - Norway
#> 194                                                                    paintedcomber
#> 195                                         PAM Harbour porpoise Borssele, 2019-2024
#> 196                                        Passive Acoustic Monitoring (PAM) STRAITS
#> 197                                                                             PC4C
#> 198             Permanent acoustic receiver array in the River Grote Nete since 2019
#> 199                                                                PhD Barbara Koeck
#> 200                                                                PhD Jeremy Pastor
#> 201                                                                        PhD_Nolan
#> 202                                                                         PhysFish
#> 203                       Pilot permanent deployment acoustic array Gibraltar Strait
#> 204                                   Porbeagle Tracking Network in Brittany, France
#> 205                          Predators and prey around renewable energy developments
#> 206                                                                        PTN-MARSW
#> 207                                                                  PTN_PROTECT2012
#> 208                                                                  PTN_PROTECT2013
#> 209                                                           PTN-Silver eel-Mondego
#> 210                                                          Purewind fish detectors
#> 211                                                                     RECCRU_array
#> 212              Receiver network in Killary Harbour and River Erriff from 2014-2024
#> 213  Redes de Sensores submarinos autonomos para la medida de indicadores biologicos
#> 214                                                                         Reelease
#> 215                 Research on the impact of management actions on beaver behaviour
#> 216                                                                           ResMed
#> 217   Restoration of Baltic sturgeon stock in Oder river & in Mecklenburg-Vorpommern
#> 218                                                River_lamprey_River Trent_2020_21
#> 219                                             River_Lamprey_Yorkshire Ouse_2018-20
#> 220                                             River Usk receiver network 2021-2024
#> 221                                                                rt2020_zeeschelde
#> 222                                                             Ruim_baan_voor_vis_2
#> 223                                                                      Running_eel
#> 224                                                                       Saeftinghe
#> 225                                               Salmon_migration_eastern_Greenland
#> 226                                                                          SAMARCH
#> 227                                                                       SARTELARAM
#> 228                                                                         SARTELTG
#> 229                                                                    SARTELZINGARO
#> 230                                                                           SCHUFI
#> 231                                                                         Scytrack
#> 232                                                                       SeaMonitor
#> 233           SeaMonitor - Costs and Pathways of Marine Migration in Atlantic salmon
#> 234                                                        SeaMonitor - GMIT Project
#> 235                                                        sea trout_2018-9_gullmarn
#> 236 SEAWave: small cetacean presence at the EMEC Orkney Billia Croo wave energy site
#> 237           SIARC network of scientific moorings in Pen Llŷn a’r Sarnau SAC, Wales
#> 238                                                                 Siganid_East_Med
#> 239                                                               Siganid_Gulf_Aqaba
#> 240              Silver Eel downstream migration in the Walloon Meuse - 2021 to 2024
#> 241       Silver European Eel escapement success and migration patterns in River Ems
#> 242                                                         Skagerrak-NorthSea-array
#> 243                                                 Skagerrak_temeletry_array_Norway
#> 244                                                                        Skye 2017
#> 245                                                             SMOLTRACK-I-Engeland
#> 246                                                            SMOLTRACK-II-Engeland
#> 247         Spatial Ecology of spurdog (Squalus acanthias) in a Scottish loch system
#> 248 Spawning migration of pike in MatsaluBay and RiverKasari (Baltic Sea, 2018-2020)
#> 249  Spawning migration of pike in Teorehe-Sauemeri floodplain (BalticSea 2017-2019)
#> 250                                                                        SPAWNSEIS
#> 251                                                                 SPIDER_GNB_array
#> 252                                                                S_rivulatus_Aqaba
#> 253                                                S_rivulatus_Eastern_Mediterranean
#> 254                                                                      STR_MOV_ANG
#> 255                                                     Sturgeon_reintroduction_Ebre
#> 256                                                  Sud_le_Impuls_voor_Diadrome_Vis
#> 257                                                    Sud_le_Innovatieve_monitoring
#> 258                                          survival_movement_elasmobranch_Adriatic
#> 259                                                                  SVNL-FISH-WATCH
#> 260                                                            Swedish eel migration
#> 261                                                                     SWIMWAY_2021
#> 262                                                           Swimway Rijnland Array
#> 263                                                                   Swimway Vechte
#> 264                                                 Swiss Acoustic Telemetry Network
#> 265   Tagging and tracking butterfly ray with acoustic telemetry in the Balearic Sea
#> 266                                  Temporary acoustic network in the Sines harbour
#> 267    Temporary acoustic network in the SW Alentejo and Vicentine Coast Marine Park
#> 268                                  Temporary acoustic receiver network in Bråviken
#> 269                     Temporary receiver array in Lithuanian rivers from 2014-2015
#> 270                                                                             TeRi
#> 271                                                                       Test VR2AR
#> 272                                                     The Bergen Telemetry Network
#> 273         The National Programme for Monitoring the Aquatic Environment and Nature
#> 274                                                                     Thorntonbank
#> 275                                                                  Trent¨_Tracking
#> 276                                                   Turkish Straits Detection Data
#> 277                         Turkish Telemetry Array in the eastern Mediterranean sea
#> 278       Understanding the movement of dolphinfish in the Mediterranean FAD fishery
#> 279                      Understand movement and life history of trout: Isle of Skye
#> 280    Underwater acoustic data from the Belgian ARMS-MBON hard-substrate monitoring
#> 281                                                             Unlocking the Severn
#> 282                  Unravelling the migrations of the invasive blue crab in Algarve
#> 283                                                                 VFM_BalticProper
#> 284                                                                 VFM_GulfOfBotnia
#> 285                                                                    VFM_Hjalmaren
#> 286                                                                      VFM_Malaren
#> 287                                                                    VFM_RiverGota
#> 288                                                                       VFM_Siljan
#> 289                                                                      VFM_Vattern
#> 290                                                              VFM_WestCoastCostal
#> 291                                                           Vissen_voor_verbinding
#> 292                                       West Coast Tracking Project Receiver Array
#> 293                                                                  Westerschelde 1
#> 294                                                                  Westerschelde 2
#> 295                                                                  Westerschelde 3
#> 296                                                       Winde Tjeukemeer 2023-2026
#> 297                                      Yellow eel movement behaviour in the Azores
#> 298                                                                       Zeeschelde
#> 299                                                                 2010_phd_reubens
#> 300                                                            2010_phd_reubens_sync
#> 301                                                                       2011_Loire
#> 302                                                                  2011 Rivierprik
#> 303                                                               2012 Leopoldkanaal
#> 304                                                                2013 Albertkanaal
#> 305                                                                       2014 Demer
#> 306                                                                       2014_Frome
#> 307                                                                        2014_Nene
#> 308                                                        2015_Albertkanaal_VPS_Ham
#> 309                                                                       2015 Dijle
#> 310                                                                     2015_Homarus
#> 311                                                            2015 PhD Verhelst_cod
#> 312                                                            2015 PhD Verhelst_eel
#> 313                                                        2016_Albertkanaal_VPS_Ham
#> 314                                                               2016 PhD Vergeynst
#> 315                                                        2017_Albertkanaal_VPS_Ham
#> 316                                                                   2019_Grotenete
#> 317                                                                   2021_Dijle_VPS
#> 318                                                         2021_Sturgeons_Danube_BG
#> 319                                                    2022_Albertkanaal_VPS_Hasselt
#> 320   Acoustic telemetry data for Atlantic cod at an oil and gas platform in Denmark
#> 321        Acoustic telemetry data for blue crab in the S'Ena Arrubia lagoon (Italy)
#> 322         Acoustic telemetry data for coastal fishes in Marintique Island (France)
#> 323    Acoustic telemetry data for Dicentrarchus labrax in the Gulf of Lion (France)
#> 324 Acoustic telemetry data for elasmobranch species in Northern Ireland (2024-2030)
#> 325    Acoustic telemetry data for garfish (Belone belone), Western Baltic (Denmark)
#> 326  Acoustic telemetry data for porbeagle sharks (Lamna nasus) tagged across Europe
#> 327          Acoustic telemetry data for Spicara smaris on the east coast of Corsica
#> 328 Acoustic telemetry data of Atlantic salmon and sea trout in Galway and Dunkellin
#> 329              Acoustic telemetry data of Carp in lake Markermeer, the Netherlands
#> 330    Acoustic telemetry for Atlantic mackerel in the German Bight of the North Sea
#> 331 Acoustic Telemetry on blue sharks (Prionace glauca) in the Basque country, Spain
#> 332                                                                           AFICHE
#> 333                                                                       ARAISOLA02
#> 334                                                                       ARAISOLA03
#> 335                                                                              Ars
#> 336                                                                         Artevigo
#> 337        Balearic strategy for climate change monitoring and prediction in the Med
#> 338                                                        Balearic Tracking Network
#> 339                  Balearic Tracking Network - Spanish Deep Water Receiver Network
#> 340                                                                         CodNoise
#> 341      Comparative study of marble and rainbow trout behaviour in Kanomljica River
#> 342 Conventional and electronic telemetry data for starry smooth-hound in NEAtlantic
#> 343                                                                    DAbecasis PhD
#> 344                                                                    DAK 2018-2019
#> 345                                                                 Danube_Sturgeons
#> 346                                                         Delfzijl Drie Delfzijlen
#> 347   Dusky grouper´s resettlement - Acoustic telemetry in Maro-Cerro Gordo´s cliffs
#> 348                                                                             EMMN
#> 349                                                                             ESGL
#> 350                                                       ETN_animal_project_group_1
#> 351                                                       ETN_animal_project_group_2
#> 352                                                       ETN_animal_project_group_3
#> 353                                                       ETN_animal_project_group_4
#> 354                                                       ETN_animal_project_group_5
#> 355                                                       ETN_animal_project_group_6
#> 356                                                       ETN_animal_project_group_7
#> 357                                                       ETN_animal_project_group_8
#> 358                                                       ETN_animal_project_group_9
#> 359   Evaluation of the effectiveness of the Balearic Islands Marine Reserve Network
#> 360  High-frequency data for rocky reef fishes in the northwestern Mediterranean sea
#> 361                                                                        Hunze_eel
#> 362                                                              JSATS-PalmaBay-2019
#> 363                                                                         Limfjord
#> 364                                                          Marble vs rainbow trout
#> 365                                                                       MBA_Massmo
#> 366                                                                      MBA_Wavehub
#> 367                                                                     MBA_Whitsand
#> 368                                                          Middle_Danube_sturgeons
#> 369          Migration of common bream in the Zuidelijke Randmeren, the Netherlands.
#> 370                                                                      Mobula Imar
#> 371      Movement and habitat connectivity of Atlantic cod in a coastal fjord system
#> 372   MPAs' effect on Balearic chondrichthyes' biodiversity using acoustic telemetry
#> 373  Multispecies acoustic telemetry data from fine-scale positioning system MarGate
#> 374                                                         Noordzeekanaal 2017-2018
#> 375                                                   North Aegean Anguilla Tracking
#> 376                                                                    NTNU-Gaulosen
#> 377                                                       NTNU River Nidelva Project
#> 378                                                Open Protocols scientific testing
#> 379                                                                       Orsted Cod
#> 380                                                                  OTN-Hemnfjorden
#> 381                                                                 OTN-Tosenfjorden
#> 382                                                           OTN VR2W Loan - Norway
#> 383                                                                PhD Barbara Koeck
#> 384                                                                     PhD_Goossens
#> 385                                                                PhD Jeremy Pastor
#> 386                                                                         PhysFish
#> 387                                                           PTN-Silver eel-Mondego
#> 388                                                                         Reelease
#> 389                                                                   Rijke_Noordzee
#> 390                                                                       SARTELARAM
#> 391                                                                         SARTELTG
#> 392                                                                    SARTELZINGARO
#> 393                                                                         Scytrack
#> 394                                                        sea trout_2018-9_gullmarn
#> 395                                                                 Siganid_East_Med
#> 396                                                               Siganid_Gulf_Aqaba
#> 397                                Silver eel migration in the Gudena River, Denmark
#> 398                                     Silver eel migration in the Warnow catchment
#> 399          Silver eel migration patterns in lowland rivers and lagoon in Lithuania
#> 400       Silver European Eel escapement success and migration patterns in River Ems
#> 401         Spatial Ecology of spurdog (Squalus acanthias) in a Scottish loch system
#> 402                                                S_rivulatus_Eastern_Mediterranean
#> 403                                                     Sturgeon_reintroduction_Ebre
#> 404   Tagging and tracking butterfly ray with acoustic telemetry in the Balearic Sea
#> 405                                                                             TeRi
#> 406                      Tracking anadromous brown trout at sea by data storage tags
#> 407  Tracking movements of 15 Dusky groupers released in the harbor of Sines in 2021
#> 408                          Tracking twaite shads at sea by using data storage tags
#> 409                 Trap and transport of silver eels from a reservoir to an estuary
#> 410       Understanding the movement of dolphinfish in the Mediterranean FAD fishery
#> 411                                                                    VPS Duurswold
#> 412                                                                  VPS Garmerwolde
#> 413                                      Yellow eel movement behaviour in the Azores
#>        type
#> 1   network
#> 2   network
#> 3   network
#> 4   network
#> 5   network
#> 6   network
#> 7   network
#> 8   network
#> 9   network
#> 10  network
#> 11  network
#> 12  network
#> 13  network
#> 14  network
#> 15  network
#> 16  network
#> 17  network
#> 18  network
#> 19  network
#> 20  network
#> 21  network
#> 22  network
#> 23  network
#> 24  network
#> 25  network
#> 26  network
#> 27  network
#> 28  network
#> 29  network
#> 30  network
#> 31  network
#> 32  network
#> 33  network
#> 34  network
#> 35  network
#> 36  network
#> 37  network
#> 38  network
#> 39  network
#> 40  network
#> 41  network
#> 42  network
#> 43  network
#> 44  network
#> 45  network
#> 46  network
#> 47  network
#> 48  network
#> 49  network
#> 50  network
#> 51  network
#> 52  network
#> 53  network
#> 54  network
#> 55  network
#> 56  network
#> 57  network
#> 58  network
#> 59  network
#> 60  network
#> 61  network
#> 62  network
#> 63  network
#> 64  network
#> 65  network
#> 66  network
#> 67  network
#> 68  network
#> 69  network
#> 70  network
#> 71  network
#> 72  network
#> 73  network
#> 74  network
#> 75  network
#> 76  network
#> 77  network
#> 78  network
#> 79  network
#> 80  network
#> 81  network
#> 82  network
#> 83  network
#> 84  network
#> 85  network
#> 86  network
#> 87  network
#> 88  network
#> 89  network
#> 90  network
#> 91  network
#> 92  network
#> 93  network
#> 94  network
#> 95  network
#> 96  network
#> 97  network
#> 98  network
#> 99  network
#> 100 network
#> 101 network
#> 102 network
#> 103 network
#> 104 network
#> 105 network
#> 106 network
#> 107 network
#> 108 network
#> 109 network
#> 110 network
#> 111 network
#> 112 network
#> 113 network
#> 114 network
#> 115 network
#> 116 network
#> 117 network
#> 118 network
#> 119 network
#> 120 network
#> 121 network
#> 122 network
#> 123 network
#> 124 network
#> 125 network
#> 126 network
#> 127 network
#> 128 network
#> 129 network
#> 130 network
#> 131 network
#> 132 network
#> 133 network
#> 134 network
#> 135 network
#> 136 network
#> 137 network
#> 138 network
#> 139 network
#> 140 network
#> 141 network
#> 142 network
#> 143 network
#> 144 network
#> 145 network
#> 146 network
#> 147 network
#> 148 network
#> 149 network
#> 150 network
#> 151 network
#> 152 network
#> 153 network
#> 154 network
#> 155 network
#> 156 network
#> 157 network
#> 158 network
#> 159 network
#> 160 network
#> 161 network
#> 162 network
#> 163 network
#> 164 network
#> 165 network
#> 166 network
#> 167 network
#> 168 network
#> 169 network
#> 170 network
#> 171 network
#> 172 network
#> 173 network
#> 174 network
#> 175 network
#> 176 network
#> 177 network
#> 178 network
#> 179 network
#> 180 network
#> 181 network
#> 182 network
#> 183 network
#> 184 network
#> 185 network
#> 186 network
#> 187 network
#> 188 network
#> 189 network
#> 190 network
#> 191 network
#> 192 network
#> 193 network
#> 194 network
#> 195 network
#> 196 network
#> 197 network
#> 198 network
#> 199 network
#> 200 network
#> 201 network
#> 202 network
#> 203 network
#> 204 network
#> 205 network
#> 206 network
#> 207 network
#> 208 network
#> 209 network
#> 210 network
#> 211 network
#> 212 network
#> 213 network
#> 214 network
#> 215 network
#> 216 network
#> 217 network
#> 218 network
#> 219 network
#> 220 network
#> 221 network
#> 222 network
#> 223 network
#> 224 network
#> 225 network
#> 226 network
#> 227 network
#> 228 network
#> 229 network
#> 230 network
#> 231 network
#> 232 network
#> 233 network
#> 234 network
#> 235 network
#> 236 network
#> 237 network
#> 238 network
#> 239 network
#> 240 network
#> 241 network
#> 242 network
#> 243 network
#> 244 network
#> 245 network
#> 246 network
#> 247 network
#> 248 network
#> 249 network
#> 250 network
#> 251 network
#> 252 network
#> 253 network
#> 254 network
#> 255 network
#> 256 network
#> 257 network
#> 258 network
#> 259 network
#> 260 network
#> 261 network
#> 262 network
#> 263 network
#> 264 network
#> 265 network
#> 266 network
#> 267 network
#> 268 network
#> 269 network
#> 270 network
#> 271 network
#> 272 network
#> 273 network
#> 274 network
#> 275 network
#> 276 network
#> 277 network
#> 278 network
#> 279 network
#> 280 network
#> 281 network
#> 282 network
#> 283 network
#> 284 network
#> 285 network
#> 286 network
#> 287 network
#> 288 network
#> 289 network
#> 290 network
#> 291 network
#> 292 network
#> 293 network
#> 294 network
#> 295 network
#> 296 network
#> 297 network
#> 298 network
#> 299  animal
#> 300  animal
#> 301  animal
#> 302  animal
#> 303  animal
#> 304  animal
#> 305  animal
#> 306  animal
#> 307  animal
#> 308  animal
#> 309  animal
#> 310  animal
#> 311  animal
#> 312  animal
#> 313  animal
#> 314  animal
#> 315  animal
#> 316  animal
#> 317  animal
#> 318  animal
#> 319  animal
#> 320  animal
#> 321  animal
#> 322  animal
#> 323  animal
#> 324  animal
#> 325  animal
#> 326  animal
#> 327  animal
#> 328  animal
#> 329  animal
#> 330  animal
#> 331  animal
#> 332  animal
#> 333  animal
#> 334  animal
#> 335  animal
#> 336  animal
#> 337  animal
#> 338  animal
#> 339  animal
#> 340  animal
#> 341  animal
#> 342  animal
#> 343  animal
#> 344  animal
#> 345  animal
#> 346  animal
#> 347  animal
#> 348  animal
#> 349  animal
#> 350  animal
#> 351  animal
#> 352  animal
#> 353  animal
#> 354  animal
#> 355  animal
#> 356  animal
#> 357  animal
#> 358  animal
#> 359  animal
#> 360  animal
#> 361  animal
#> 362  animal
#> 363  animal
#> 364  animal
#> 365  animal
#> 366  animal
#> 367  animal
#> 368  animal
#> 369  animal
#> 370  animal
#> 371  animal
#> 372  animal
#> 373  animal
#> 374  animal
#> 375  animal
#> 376  animal
#> 377  animal
#> 378  animal
#> 379  animal
#> 380  animal
#> 381  animal
#> 382  animal
#> 383  animal
#> 384  animal
#> 385  animal
#> 386  animal
#> 387  animal
#> 388  animal
#> 389  animal
#> 390  animal
#> 391  animal
#> 392  animal
#> 393  animal
#> 394  animal
#> 395  animal
#> 396  animal
#> 397  animal
#> 398  animal
#> 399  animal
#> 400  animal
#> 401  animal
#> 402  animal
#> 403  animal
#> 404  animal
#> 405  animal
#> 406  animal
#> 407  animal
#> 408  animal
#> 409  animal
#> 410  animal
#> 411  animal
#> 412  animal
#> 413  animal